'====================================================================
' PROGRAM: Hallow99.BAS
'====================================================================
'
' Date : October 2, 1999
' By : Mike Genovy
'
' A program to control Halloween decorations, based on IR input.
' ( At last we get rid of the old "Witches Mat" )
' 
' This program runs on the LEGO Controller card.
'--------------------------------------------------------------------
'
' This hardware uses a standard Universal Remote Control as the IR 
' transmitter. The IR receiver is scrounged from a VCR. The IR Receiver
' portion of an old VCR front panel control board was used. The output
' of this circuit is first fed to a 555 timer missing pulse circuit, 
' to eliminate problems with how the Universal Remote sends out a signal.
' It does not send out a continuous signal, but rather bursts, which
' vary depending of what button is pushed.
'
' Note that one could use a 555 timer and an IR LED as and IR transmitter.
' This would eliminate the problem with the Remote and burst type signals.
'
' The program sends a serial output to an XT computer when the IR sensor 
' is activated. This serial output is used by the XT to trigger X10 
' commands for dimming the Halloween lights. The XT runs a program by
' Bruce Christenson ( FX.EXE )which allows one to execute a predefined 
' script of X10 commands.
'
' The program also triggers the witches scream box when the IR beam is 
' activated. This is done via the general purpose relay output on Pin 5.
'
' The Motor PWM output and Forward/Reverse relays are used to control a
' motor used to lower and raise a spider attached to a string and drum
' assembly. The motor speed is controlled with an IR510 MOSFET attached
' to Pin 2. 
'
'
' PORT ASSIGNMENTS FOR LEGO CONTROLLER BOARD
' ------------------------------------------
'
' Pin 0 ( 7 )  - Serial Input for PC  ( data to PC )
' Pin 1 ( 8 )  - Serial Output For PC ( data from PC )
' Pin 2 ( 9 )  - PWM output to Motor # 1 MOSFET Driver
' Pin 3 ( 10 ) - Motor # 1 Forward relay
' Pin 4 ( 11 ) - Motor # 1 Reverse relay
' Pin 5 ( 12 ) - Output to general purpose relay
' Pin 6 ( 13 ) - Input from whatever you wish
' Pin 7 ( 14 ) - Input from IR Missing Pulse circuit (555 timer)   
'
' Pin 2 is used for LEGO motor PWM speed control.
' Pin 3 & 4 are Forward and Reverse relay control.
' Pin 5 is a general purpose relay ( for Steering of robot ) 
' Pin 6 is from bumper switches on the LEGO robot. 
' ( for Halloween this can be from whatever ?? )
' Pin 7 is from the IR missing pulse circuit. This allows a TV
' remote to be used to control the robot.
'
' NOTE: In the above table Pin n refers to the PORT designation when 
' programming in Basic. The number in ( ) is the actual pin on the
' Basic Stamp 1 circuit board.
'
'-----------------------------------------------------------------

dirs = %00111100		'Port direction register
				'Pin 2,3,4,5 = Outputs
b2=175				'Motor Speed value
'
'Check on how much Eprom space has been used by this program
' 255 - value of b4 = # of code bytes
'
READ 255,b4		'Get value
debug b4			'Send value to port


'==========================================================================
'			         MAIN ROUTINE
'==========================================================================
'
' Pin 7 is connected to the IR Missing Pulse circuit. This is a 555 timer
' which produces a low output when an input pulse is missed. The input
' pulse interval is set by a pot, allowing different buttons on the IR
' remote to be used to control the motor.
'
'--------------------------------------------------------------------------
'
' The Main Loop simply waits for the IR sensor to be triggered.
'
ReadIR:
	if pin7 = 1 then Trigger  	 	'See if IR sensor triggered
	b2 = pin7					'send pin7 value to port for
	debug b2					'debugging 
	goto ReadIR					'Go back and check it again

'=================================================================
' Trigger Routine
'=================================================================

Trigger:

	pin5 = 1				'Turn on General Purpose relay
						'to activate witches scream device
	serout 1,N2400,("I")		'Send I char data to PC serial port
	pin5 = 0				'Turn off General Purpose relay
						'to deactivate witches scream device
'
' Now we can either go back and wait for another trigger, or turn 
' on the motor and lower the spider !!
'
	goto SpiderControl	'Lower the spider !!
'	goto ReadIR			'Skip spider and wait for another IR trigger

'=================================================================
' Spider Control
'=================================================================

SpiderControl:

'--------------------------------------------------------------------------
' The spider is controlled by a motor with drum & cord assembly.
' The motor is simply turned on for a predefined time in one direction,
' then the other direction.
'--------------------------------------------------------------------------

	pin3 = 1			'Turn on Forward relay ( or Down relay )
	pin2 = 1			'Apply power to motor 
	pause 100			'Wait for spider to lower to position
	pin2 = 0			'Remove power to motor
	pin3 = 0			'Turn off Forward relay ( or Down relay )
'
' The spider is now in the down position. Wait a bit and then raise the
' spider.
'
	pin4 = 1			'Turn on Reverse relay ( or Up relay )
	pin2 = 1			'Apply power to motor 
	pause 100			'Wait for spider to raise to position
	pin2 = 0			'Remove power to motor
	pin4 = 0			'Turn off Forward relay ( or Up relay )

	Goto ReadIR			'Go back and wait for IR sensor trigger


